==> haskell-genvalidity-hspec-0.7.0.4-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-hspec
version:              0.7.0.4
visibility:           public
id:                   genvalidity-hspec-0.7.0.4-IdgM8XArscpGhP2BJLlVUQ
key:                  genvalidity-hspec-0.7.0.4-IdgM8XArscpGhP2BJLlVUQ
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  85044db3fbb05150cd9b8a8b1a809d34
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor
    Test.Validity.GenRelativeValidity Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.RelativeValidity Test.Validity.Show
    Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-8.10.2/site-local/genvalidity-hspec-0.7.0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/genvalidity-hspec-0.7.0.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/genvalidity-hspec-0.7.0.4

hs-libraries:         HSgenvalidity-hspec-0.7.0.4-IdgM8XArscpGhP2BJLlVUQ
depends:
    QuickCheck-2.14.1-9QGOOtk2Q9p4Zfm3TyYrdl base-4.14.1.0
    genvalidity-0.11.0.0-HculUyw1rswmtkzqp8X60
    genvalidity-property-0.5.0.1-nm5NqfesQ6aUiiMwqlhc
    hspec-2.7.4-32F9MGlTMvUDJZmIetsvIN
    hspec-core-2.7.4-Egk46QyEQrkH0oSRzcSZjL transformers-0.5.6.2
    validity-0.11.0.0-1by4ilJkFWhDKAfkO6LAOq

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-hspec-0.7.0.4-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-hspec
version:              0.7.0.4
visibility:           public
id:                   genvalidity-hspec-0.7.0.4-LpQ9PLmYbJGCvgdigeDX6l
key:                  genvalidity-hspec-0.7.0.4-LpQ9PLmYbJGCvgdigeDX6l
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  502f2361dd9e59dfd9fce67a1382720f
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor
    Test.Validity.GenRelativeValidity Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.RelativeValidity Test.Validity.Show
    Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-8.10.2/site-local/genvalidity-hspec-0.7.0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/genvalidity-hspec-0.7.0.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/genvalidity-hspec-0.7.0.4

hs-libraries:         HSgenvalidity-hspec-0.7.0.4-LpQ9PLmYbJGCvgdigeDX6l
depends:
    QuickCheck-2.14.1-64ImYjtdVDWOmMrx53wi base-4.14.1.0
    genvalidity-0.11.0.0-4nxOK6ljyiJH3CwntnIP3X
    genvalidity-property-0.5.0.1-LuR1RqfFQWHHCzPrdhKjEG
    hspec-2.7.4-FApJ2WRwN1WEcXqteLOTi8
    hspec-core-2.7.4-8q2tgO7kR54BNa8cu9VTMJ transformers-0.5.6.2
    validity-0.11.0.0-IJoS8TafVwAA5R4Sj8vsJr

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
